summaryrefslogtreecommitdiffstats
path: root/libhb
diff options
context:
space:
mode:
Diffstat (limited to 'libhb')
-rw-r--r--libhb/sync.c10
1 files changed, 5 insertions, 5 deletions
diff --git a/libhb/sync.c b/libhb/sync.c
index 9bc94de02..f199feff8 100644
--- a/libhb/sync.c
+++ b/libhb/sync.c
@@ -1761,12 +1761,12 @@ static int UpdateSCR( sync_stream_t * stream, hb_buffer_t * buf )
{
// This should happen extremely rarely if ever.
// But if we get here, this is the first buffer received for
- // this stream. Normally, some buffers will be queued for
+ // this stream. Normally, some buffers will be queued for
// every stream before we ever call UpdateSCR.
- // We don't really know what it's timestamp should be,
- // but 0 is a good guess.
- buf->s.start = 0;
- last_scr_pts = buf->s.start;
+ // We don't really know what it's timestamp should be.
+ // So drop the buffer.
+ hb_buffer_close(&buf);
+ return 0;
}
if (buf->s.stop != AV_NOPTS_VALUE)
{